// KreateCD - CD recording software for the K desktop environment
//
// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
//
// This file is subject to the terms and conditions of the GNU General
// Public License.  See the file COPYING in the main directory of the
// KreateCD distribution for more details.

int getRootRights();
int dropRootRights();

#define ROOT_CALLED  ( (callUID==0) && (callGID==0) )

extern int callUID,callGID;
